////////////////////////////////////////////////////////////////////////////////
// TMoreLessButton component
//
// Component that roughly behaves like TSpinButton, except that it allows the
// control to be displayed both horizontally and vertically
//
// by Alan GARNY
//    gry@physiol.ox.ac.uk
//    http://pc-heartbreak.physiol.ox.ac.uk/
//
//  Copyright 1997-98
////////////////////////////////////////////////////////////////////////////////

#ifndef MoreLessButtonH
#define MoreLessButtonH

////////////////////////////////////////////////////////////////////////////////

#include <Buttons.hpp>

////////////////////////////////////////////////////////////////////////////////
// TMLBTimerSpeedButton

class TMLBTimerSpeedButton: public TSpeedButton
{
   friend class TMoreLessButton;

   private:
      // Properties used for internal purpose

      TTimer *RepeatTimer;

      // Methods used for internal purpose

      void __fastcall TimerExpired(TObject *aSender);

   protected:
      // Inherited methods

     void __fastcall MouseDown(TMouseButton aButton,  TShiftState aShift,
                               int aX, int aY);
     void __fastcall MouseUp(TMouseButton aButton,  TShiftState aShift,
                             int aX, int aY);

   public:
      // Constructor & Destructor

      virtual __fastcall TMLBTimerSpeedButton(TComponent *aOwner);
      virtual __fastcall ~TMLBTimerSpeedButton();
};

////////////////////////////////////////////////////////////////////////////////
// TMoreLessButton

enum TMLBOrientation {orHorizontal, orVertical};

#if (__BORLANDC__ >= 0x0530)   // i.e. NOT BCB 1.0
class PACKAGE TMoreLessButton: public TWinControl
#else
class TMoreLessButton: public TWinControl
#endif
{
   friend class TMLBTimerSpeedButton;

   private:
      // Private representation of published properties

      TMLBOrientation FOrientation;

      TNotifyEvent FOnLessClick;
      TNotifyEvent FOnMoreClick;

      // Methods to modify the different published properties

      void __fastcall SetOrientation(const TMLBOrientation aValue);

      Graphics::TBitmap* __fastcall GetMoreGlyph(void);
      Graphics::TBitmap* __fastcall GetLessGlyph(void);

      void __fastcall SetMoreGlyph(Graphics::TBitmap *aValue);
      void __fastcall SetLessGlyph(Graphics::TBitmap *aValue);

      // Properties used for internal purpose

      TMLBTimerSpeedButton *LessButton;
      TMLBTimerSpeedButton *MoreButton;

      // Methods used for internal purpose

      TMLBTimerSpeedButton* __fastcall CreateButton();

      void __fastcall BtnClick(TObject *aSender);

      void __fastcall AdjustSize();

      void __fastcall WMSize(TWMSize &aMsg);

   public:
      // Constructor & Destructor

      virtual __fastcall TMoreLessButton(TComponent *aOwner);
      virtual __fastcall ~TMoreLessButton();

      // User's methods


   __published:
      // Published properties

      __property TMLBOrientation Orientation = {read=FOrientation, write=SetOrientation, default=orVertical};

      __property Graphics::TBitmap *MoreGlyph = {read=GetMoreGlyph, write=SetMoreGlyph, nodefault};
      __property Graphics::TBitmap *LessGlyph = {read=GetLessGlyph, write=SetLessGlyph, nodefault};

      // Available events

      __property TNotifyEvent OnLessClick = {read=FOnLessClick, write=FOnLessClick};
      __property TNotifyEvent OnMoreClick = {read=FOnMoreClick, write=FOnMoreClick};

   BEGIN_MESSAGE_MAP
      MESSAGE_HANDLER(WM_SIZE, TWMSize, WMSize)
   END_MESSAGE_MAP(TWinControl)
};

////////////////////////////////////////////////////////////////////////////////

#endif

// End of file
////////////////////////////////////////////////////////////////////////////////

